@@ -9,7 +9,6 @@ from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.base import ContentFile
 from django.template import Context
-from django.templatetags.static import PrefixNode
 from django.utils.encoding import force_bytes
 from sass_processor.utils import get_custom_functions
 
@@ -36,6 +35,7 @@ class SassProcessor:
         'SASS_OUTPUT_STYLE',
         'nested' if settings.DEBUG else 'compressed')
     processor_enabled = getattr(settings, 'SASS_PROCESSOR_ENABLED', settings.DEBUG)
+    fail_silently = getattr(settings, 'SASS_PROCESSOR_FAIL_SILENTLY', not settings.DEBUG)
     sass_extensions = ('.scss', '.sass')
     node_npx_path = getattr(settings, 'NODE_NPX_PATH', 'npx')
 
@@ -61,7 +61,7 @@ class SassProcessor:
             return css_filename
         sourcemap_filename = css_filename + '.map'
         base = os.path.dirname(filename)
-        if find_file(css_filename) and self.is_latest(sourcemap_filename, base):
+        if self.storage.exists(css_filename) and self.is_latest(sourcemap_filename, base):
             return css_filename
 
         # with offline compilation, raise an error, if css file could not be found.
@@ -81,8 +81,14 @@ class SassProcessor:
             compile_kwargs['precision'] = self.sass_precision
         if self.sass_output_style:
             compile_kwargs['output_style'] = self.sass_output_style
-        content, sourcemap = sass.compile(**compile_kwargs)
-        content, sourcemap = force_bytes(content), force_bytes(sourcemap)
+        try:
+            content, sourcemap = (force_bytes(output) for output in sass.compile(**compile_kwargs))
+        except sass.CompileError as exc:
+            if self.fail_silently:
+                content, sourcemap = force_bytes(exc), None
+                logger.error(exc)
+            else:
+                raise exc
 
         # autoprefix CSS files using postcss in external JavaScript process
         if self.node_npx_path and os.path.isdir(self.node_modules_dir or ''):
@@ -107,7 +113,8 @@ class SassProcessor:
         self.storage.save(css_filename, ContentFile(content))
         if self.storage.exists(sourcemap_filename):
             self.storage.delete(sourcemap_filename)
-        self.storage.save(sourcemap_filename, ContentFile(sourcemap))
+        if sourcemap:
+            self.storage.save(sourcemap_filename, ContentFile(sourcemap))
         return css_filename
 
     def resolve_path(self, context=None):
@@ -119,12 +126,11 @@ class SassProcessor:
         _, ext = os.path.splitext(self.resolve_path())
         return ext in self.sass_extensions
 
-    def is_latest(self, sourcemap_filename, base):
-        sourcemap_file = find_file(sourcemap_filename)
-        if not sourcemap_file or not os.path.isfile(sourcemap_file):
+    def is_latest(self, sourcemap_file, base):
+        if not self.storage.exists(sourcemap_file):
             return False
-        sourcemap_mtime = os.stat(sourcemap_file).st_mtime
-        with open(sourcemap_file, 'r') as fp:
+        sourcemap_mtime = self.storage.get_modified_time(sourcemap_file).timestamp()
+        with self.storage.open(sourcemap_file, 'r') as fp:
             sourcemap = json.load(fp)
         for srcfilename in sourcemap.get('sources'):
             srcfilename = os.path.join(base, srcfilename)
@@ -135,11 +141,7 @@ class SassProcessor:
 
     @classmethod
     def handle_simple(cls, path):
-        if apps.is_installed('django.contrib.staticfiles'):
-            from django.contrib.staticfiles.storage import staticfiles_storage
-            return staticfiles_storage.url(path)
-        else:
-            return urljoin(PrefixNode.handle_simple('STATIC_URL'), quote(path))
+        return cls.storage.url(path)
 
 _sass_processor = SassProcessor()
 def sass_processor(filename):
